==> worker-2.8.3.tar.bz2: worker-2.8.3/src/shortkeyfromlistop.cc <==
/* shortkeyfromlist.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: shortkeyfromlistop.cc,v 1.2 2003/05/04 01:16:30 ralf Exp $ */

#include "shortkeyfromlistop.h"
#include "listermode.h"
#include "normalmode.h"
#include "worker.h"

const char *ShortkeyFromListOp::name="ShortkeyFromListOp";

ShortkeyFromListOp::ShortkeyFromListOp() : FunctionProto()
{
}

ShortkeyFromListOp::~ShortkeyFromListOp()
{
}

ShortkeyFromListOp*
ShortkeyFromListOp::duplicate() const
{
  ShortkeyFromListOp *ta=new ShortkeyFromListOp();
  return ta;
}

bool
ShortkeyFromListOp::isName(const char *str)
{
  if(strcmp(str,name)==0) return true; else return false;
}

const char *
ShortkeyFromListOp::getName()
{
  return name;
}

int
ShortkeyFromListOp::run(ActionMessage *msg)
{
  if(msg->mode!=msg->AM_MODE_DNDACTION) {
    msg->getWorker()->activateShortkeyFromList();
  }
  return 0;
}

const char *
ShortkeyFromListOp::getDescription()
{
  return catalog.getLocaleCom(42);
}

==> worker-2.13.1.tar.bz2: worker-2.13.1/src/shortkeyfromlistop.cc <==
/* shortkeyfromlist.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: shortkeyfromlistop.cc,v 1.5 2005/10/19 18:01:35 ralf Exp $ */

#include "shortkeyfromlistop.h"
#include "listermode.h"
#include "normalmode.h"
#include "worker.h"

const char *ShortkeyFromListOp::name="ShortkeyFromListOp";

ShortkeyFromListOp::ShortkeyFromListOp() : FunctionProto()
{
}

ShortkeyFromListOp::~ShortkeyFromListOp()
{
}

ShortkeyFromListOp*
ShortkeyFromListOp::duplicate() const
{
  ShortkeyFromListOp *ta=new ShortkeyFromListOp();
  return ta;
}

bool
ShortkeyFromListOp::isName(const char *str)
{
  if(strcmp(str,name)==0) return true; else return false;
}

const char *
ShortkeyFromListOp::getName()
{
  return name;
}

int
ShortkeyFromListOp::run( WPUContext *wpu, ActionMessage *msg )
{
  if(msg->mode!=msg->AM_MODE_DNDACTION) {
    msg->getWorker()->activateShortkeyFromList();
  }
  return 0;
}

const char *
ShortkeyFromListOp::getDescription()
{
  return catalog.getLocaleCom(42);
}
